@@ -4,7 +4,7 @@ test_that("FSelectorExhaustive", {
   test_fselector("exhaustive_search", term_evals = 2, real_evals = 4)
   test_fselector("exhaustive_search", term_evals = 4, real_evals = 4)
 
-  z = test_fselector("exhaustive_search", term_evals = 15)
+  z = test_fselector("exhaustive_search", term_evals = 15, store_models = TRUE)
   a = z$inst$archive$data()
   expect_feature_number(a[batch_nr == 1, 1:4], n = 1)
   expect_feature_number(a[batch_nr == 2, 1:4], n = 2)
@@ -16,7 +16,8 @@ test_that("FSelectorExhaustive", {
     x3 = TRUE,
     x4 = FALSE))
 
-  z = test_fselector("exhaustive_search", max_features = 2, term_evals = 10)
+  z = test_fselector("exhaustive_search", max_features = 2, term_evals = 10,
+    store_models = TRUE)
   a = z$inst$archive$data()
   expect_max_features(a[, 1:4], n = 2)
   r = z$inst$result_x_search_space
